intelmq.bots.parsers.taichung package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.parsers.taichung package

## Submodules

## intelmq.bots.parsers.taichung.parser module

unmapped:

  : bing says “Over-the-line”,

`intelmq.bots.parsers.taichung.parser.` `BOT`

  alias of `intelmq.bots.parsers.taichung.parser.TaichungNetflowRecentParserBot`

class `intelmq.bots.parsers.taichung.parser.` `TaichungNetflowRecentParserBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.ParserBot`

  Parse the Taichung feed

  `get_type`(value)
  `parse`(report)

    A generator yielding the single elements of the data.

    Comments, headers etc. can be processed here. Data needed by self.parse_line can be saved in self.tempdata (list).

    Default parser yields stripped lines. Override for your use or use an existing parser, e.g.:

        parse = ParserBot.parse_csv

    You should do that for recovering lines too.

      recover_line = ParserBot.recover_line_csv

  `parse_line`(row, report)

    A generator which can yield one or more messages contained in line.

    Report has the full message, thus you can access some metadata. Override for your use.

## Module contents